/* =============================================================================
 *   Copyright (c) Texas Instruments Incorporated 2018
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

/**
 *  \file   main_dmsc.c
 *
 *  \brief  System Config implementation example.
 */

/* ========================================================================== */
/*                             Include Files                                  */
/* ========================================================================== */

#include <stdio.h>
#include <string.h>
#include <stdint.h>
#include <ti/drv/pm/pmlib.h>
#include <ti/drv/sciclient/sciclient.h>
#include "app_utils.h"

/* ========================================================================== */
/*                           Macros & Typedefs                                */
/* ========================================================================== */

/* None */

/* ========================================================================== */
/*                         Structures and Enums                               */
/* ========================================================================== */

/* None */

/* ========================================================================== */
/*                 Internal Function Declarations                             */
/* ========================================================================== */

/**<
 *  \brief Function to configure always enabled for all the modules.
 *
 *  \param  None
 *
 *  \return None
 */
void alwaysEnabledConfig(void);

/**<
 *  \brief Function to configure always disabled for all the modules.
 *
 *  \param  None
 *
 *  \return None
 */
void alwaysDisabledConfig(void);

/**<
 *  \brief Function to configure auto clock gated for all the modules.
 *
 *  \param  None
 *
 *  \return None
 */
void retentionConfig(void);

/* ========================================================================== */
/*                            Global Variables                                */
/* ========================================================================== */

int32_t    finalSuccess = PM_SUCCESS;

#if defined (SOC_AM65XX)
uint32_t gModuleNum[] = {
    TISCI_DEV_MCU_ADC0,
    TISCI_DEV_MCU_ADC1,
    TISCI_DEV_CAL0,
    TISCI_DEV_CMPEVENT_INTRTR0,
    TISCI_DEV_MCU_CPSW0,
    TISCI_DEV_CPT2_AGGR0,
    TISCI_DEV_MCU_CPT2_AGGR0,
    TISCI_DEV_STM0,
    TISCI_DEV_DCC0,
    TISCI_DEV_DCC1,
    TISCI_DEV_DCC2,
    TISCI_DEV_DCC3,
    TISCI_DEV_DCC4,
    TISCI_DEV_DCC5,
    TISCI_DEV_DCC6,
    TISCI_DEV_DCC7,
    TISCI_DEV_MCU_DCC0,
    TISCI_DEV_MCU_DCC1,
    TISCI_DEV_MCU_DCC2,
    TISCI_DEV_DDRSS0,
    TISCI_DEV_DEBUGSS_WRAP0,
    TISCI_DEV_WKUP_DMSC0,
    TISCI_DEV_TIMER0,
    TISCI_DEV_TIMER1,
    TISCI_DEV_TIMER10,
    TISCI_DEV_TIMER11,
    TISCI_DEV_TIMER2,
    TISCI_DEV_TIMER3,
    TISCI_DEV_TIMER4,
    TISCI_DEV_TIMER5,
    TISCI_DEV_TIMER6,
    TISCI_DEV_TIMER7,
    TISCI_DEV_TIMER8,
    TISCI_DEV_TIMER9,
    TISCI_DEV_MCU_TIMER0,
    TISCI_DEV_MCU_TIMER1,
    TISCI_DEV_MCU_TIMER2,
    TISCI_DEV_MCU_TIMER3,
    TISCI_DEV_ECAP0,
    TISCI_DEV_EHRPWM0,
    TISCI_DEV_EHRPWM1,
    TISCI_DEV_EHRPWM2,
    TISCI_DEV_EHRPWM3,
    TISCI_DEV_EHRPWM4,
    TISCI_DEV_EHRPWM5,
    TISCI_DEV_ELM0,
    TISCI_DEV_MMCSD0,
    TISCI_DEV_MMCSD1,
    TISCI_DEV_EQEP0,
    TISCI_DEV_EQEP1,
    TISCI_DEV_EQEP2,
    TISCI_DEV_ESM0,
    TISCI_DEV_MCU_ESM0,
    TISCI_DEV_WKUP_ESM0,
    TISCI_DEV_GIC0,
    TISCI_DEV_GPIO0,
    TISCI_DEV_GPIO1,
    TISCI_DEV_WKUP_GPIO0,
    TISCI_DEV_GPMC0,
    TISCI_DEV_GTC0,
    TISCI_DEV_PRU_ICSSG0,
    TISCI_DEV_PRU_ICSSG1,
    TISCI_DEV_PRU_ICSSG2,
    TISCI_DEV_GPU0,
    TISCI_DEV_CCDEBUGSS0,
    TISCI_DEV_DSS0,
    TISCI_DEV_DEBUGSS0,
    TISCI_DEV_EFUSE0,
    TISCI_DEV_PSC0,
    TISCI_DEV_MCU_DEBUGSS0,
    TISCI_DEV_MCU_EFUSE0,
    TISCI_DEV_PBIST0,
    TISCI_DEV_PBIST1,
    TISCI_DEV_MCU_PBIST0,
    TISCI_DEV_PLLCTRL0,
    TISCI_DEV_WKUP_PLLCTRL0,
    TISCI_DEV_MCU_ROM0,
    TISCI_DEV_WKUP_PSC0,
    TISCI_DEV_WKUP_VTM0,
    TISCI_DEV_DEBUGSUSPENDRTR0,
    TISCI_DEV_CBASS0,
    TISCI_DEV_CBASS_DEBUG0,
    TISCI_DEV_CBASS_FW0,
    TISCI_DEV_CBASS_INFRA0,
    TISCI_DEV_ECC_AGGR0,
    TISCI_DEV_ECC_AGGR1,
    TISCI_DEV_ECC_AGGR2,
    TISCI_DEV_MCU_CBASS0,
    TISCI_DEV_MCU_CBASS_DEBUG0,
    TISCI_DEV_MCU_CBASS_FW0,
    TISCI_DEV_MCU_ECC_AGGR0,
    TISCI_DEV_MCU_ECC_AGGR1,
    TISCI_DEV_WKUP_CBASS0,
    TISCI_DEV_WKUP_ECC_AGGR0,
    TISCI_DEV_WKUP_CBASS_FW0,
    TISCI_DEV_MAIN2MCU_LVL_INTRTR0,
    TISCI_DEV_MAIN2MCU_PLS_INTRTR0,
    TISCI_DEV_CTRL_MMR0,
    TISCI_DEV_GPIOMUX_INTRTR0,
    TISCI_DEV_PLL_MMR0,
    TISCI_DEV_MCU_MCAN0,
    TISCI_DEV_MCU_MCAN1,
    TISCI_DEV_MCASP0,
    TISCI_DEV_MCASP1,
    TISCI_DEV_MCASP2,
    TISCI_DEV_MCU_CTRL_MMR0,
    TISCI_DEV_MCU_PLL_MMR0,
    TISCI_DEV_MCU_SEC_MMR0,
    TISCI_DEV_I2C0,
    TISCI_DEV_I2C1,
    TISCI_DEV_I2C2,
    TISCI_DEV_I2C3,
    TISCI_DEV_MCU_I2C0,
    TISCI_DEV_WKUP_I2C0,
    TISCI_DEV_MCU_MSRAM0,
    TISCI_DEV_DFTSS0,
    TISCI_DEV_NAVSS0,
    TISCI_DEV_MCU_NAVSS0,
    TISCI_DEV_PCIE0,
    TISCI_DEV_PCIE1,
    TISCI_DEV_PDMA_DEBUG0,
    TISCI_DEV_PDMA0,
    TISCI_DEV_PDMA1,
    TISCI_DEV_MCU_PDMA0,
    TISCI_DEV_MCU_PDMA1,
    TISCI_DEV_MCU_PSRAM0,
    TISCI_DEV_PSRAMECC0,
    TISCI_DEV_MCU_ARMSS0,
    TISCI_DEV_RTI0,
    TISCI_DEV_RTI1,
    TISCI_DEV_RTI2,
    TISCI_DEV_RTI3,
    TISCI_DEV_MCU_RTI0,
    TISCI_DEV_MCU_RTI1,
    TISCI_DEV_SA2_UL0,
    TISCI_DEV_MCSPI0,
    TISCI_DEV_MCSPI1,
    TISCI_DEV_MCSPI2,
    TISCI_DEV_MCSPI3,
    TISCI_DEV_MCSPI4,
    TISCI_DEV_MCU_MCSPI0,
    TISCI_DEV_MCU_MCSPI1,
    TISCI_DEV_MCU_MCSPI2,
    TISCI_DEV_TIMESYNC_INTRTR0,
    TISCI_DEV_UART1,
    TISCI_DEV_UART2,
    TISCI_DEV_USB3SS0,
    TISCI_DEV_USB3SS1,
    TISCI_DEV_SERDES0,
    TISCI_DEV_SERDES1,
    TISCI_DEV_WKUP_CTRL_MMR0,
    TISCI_DEV_WKUP_GPIOMUX_INTRTR0,
    TISCI_DEV_BOARD0,
    TISCI_DEV_MCU_ARMSS0_CPU0,
    TISCI_DEV_WKUP_DMSC0_CORTEX_M3_0,
    TISCI_DEV_NAVSS0_CPTS0,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER0,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER1,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER2,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER3,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER4,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER5,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER6,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER7,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER8,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER9,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER10,
    TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER11,
    TISCI_DEV_NAVSS0_MCRC0,
    TISCI_DEV_NAVSS0_PVU0,
    TISCI_DEV_NAVSS0_PVU1,
    TISCI_DEV_NAVSS0_UDMASS_INTA0,
    TISCI_DEV_NAVSS0_MODSS_INTA0,
    TISCI_DEV_NAVSS0_MODSS_INTA1,
    TISCI_DEV_NAVSS0_INTR_ROUTER_0,
    TISCI_DEV_NAVSS0_TIMER_MGR0,
    TISCI_DEV_NAVSS0_TIMER_MGR1,
    TISCI_DEV_NAVSS0_PROXY0,
    TISCI_DEV_NAVSS0_RINGACC0,
    TISCI_DEV_NAVSS0_UDMAP0,
    TISCI_DEV_MCU_NAVSS0_INTR_AGGR_0,
    TISCI_DEV_MCU_NAVSS0_INTR_ROUTER_0,
    TISCI_DEV_MCU_NAVSS0_PROXY0,
    TISCI_DEV_MCU_NAVSS0_MCRC0,
    TISCI_DEV_MCU_NAVSS0_UDMAP0,
    TISCI_DEV_MCU_NAVSS0_RINGACC0,
    TISCI_DEV_COMPUTE_CLUSTER_MSMC0,
    TISCI_DEV_COMPUTE_CLUSTER_PBIST0,
    TISCI_DEV_COMPUTE_CLUSTER_CPAC0,
    TISCI_DEV_COMPUTE_CLUSTER_CPAC_PBIST0,
    TISCI_DEV_COMPUTE_CLUSTER_CPAC1,
    TISCI_DEV_COMPUTE_CLUSTER_CPAC_PBIST1,
    TISCI_DEV_COMPUTE_CLUSTER_A53_0,
    TISCI_DEV_COMPUTE_CLUSTER_A53_1,
    TISCI_DEV_COMPUTE_CLUSTER_A53_2,
    TISCI_DEV_COMPUTE_CLUSTER_A53_3,
    TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_NAVSRAMLO_4,
    TISCI_DEV_CPT2_PROBE_VBUSM_MCU_FSS_S1_3,
    TISCI_DEV_CPT2_PROBE_VBUSM_MCU_EXPORT_SLV_0,
    TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_NAVSRAMHI_3,
    TISCI_DEV_CPT2_PROBE_VBUSM_MCU_SRAM_SLV_1,
    TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_NAVDDRHI_5,
    TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_NAVDDRLO_6,
    TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_CAL0_0,
    TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_DSS_2,
    TISCI_DEV_CPT2_PROBE_VBUSM_MCU_FSS_S0_2,
    TISCI_DEV_OLDI_TX_CORE_MAIN_0,
    TISCI_DEV_K3_ARM_ATB_FUNNEL_3_32_MCU_0,
    TISCI_DEV_ICEMELTER_WKUP_0,
    TISCI_DEV_K3_LED_MAIN_0,
    TISCI_DEV_VDC_DATA_VBUSM_32B_REF_WKUP2MCU,
    TISCI_DEV_VDC_DATA_VBUSM_32B_REF_MCU2WKUP,
    TISCI_DEV_VDC_DATA_VBUSM_64B_REF_MAIN2MCU,
    TISCI_DEV_VDC_DATA_VBUSM_64B_REF_MCU2MAIN,
    TISCI_DEV_VDC_DMSC_DBG_VBUSP_32B_REF_DBG2DMSC,
    TISCI_DEV_VDC_INFRA_VBUSP_32B_REF_WKUP2MAIN_INFRA,
    TISCI_DEV_VDC_INFRA_VBUSP_32B_REF_MCU2MAIN_INFRA,
    TISCI_DEV_VDC_SOC_FW_VBUSP_32B_REF_FWWKUP2MCU,
    TISCI_DEV_VDC_SOC_FW_VBUSP_32B_REF_FWMCU2MAIN,
    TISCI_DEV_VDC_MCU_DBG_VBUSP_32B_REF_DBGMAIN2MCU,
    TISCI_DEV_VDC_NAV_PSIL_128B_REF_MAIN2MCU,
    TISCI_DEV_GS80PRG_SOC_WRAP_WKUP_0,
    TISCI_DEV_GS80PRG_MCU_WRAP_WKUP_0,
    TISCI_DEV_MX_WAKEUP_RESET_SYNC_WKUP_0,
    TISCI_DEV_MX_EFUSE_MAIN_CHAIN_MAIN_0,
    TISCI_DEV_MX_EFUSE_MCU_CHAIN_MCU_0,
    TISCI_DEV_MCU_ARMSS0_CPU1
};

char * gModuleNames[] =
{
    "TISCI_DEV_MCU_ADC0",
    "TISCI_DEV_MCU_ADC1",
    "TISCI_DEV_CAL0",
    "TISCI_DEV_CMPEVENT_INTRTR0",
    "TISCI_DEV_MCU_CPSW0",
    "TISCI_DEV_CPT2_AGGR0",
    "TISCI_DEV_MCU_CPT2_AGGR0",
    "TISCI_DEV_STM0",
    "TISCI_DEV_DCC0",
    "TISCI_DEV_DCC1",
    "TISCI_DEV_DCC2",
    "TISCI_DEV_DCC3",
    "TISCI_DEV_DCC4",
    "TISCI_DEV_DCC5",
    "TISCI_DEV_DCC6",
    "TISCI_DEV_DCC7",
    "TISCI_DEV_MCU_DCC0",
    "TISCI_DEV_MCU_DCC1",
    "TISCI_DEV_MCU_DCC2",
    "TISCI_DEV_DDRSS0",
    "TISCI_DEV_DEBUGSS_WRAP0",
    "TISCI_DEV_WKUP_DMSC0",
    "TISCI_DEV_TIMER0",
    "TISCI_DEV_TIMER1",
    "TISCI_DEV_TIMER10",
    "TISCI_DEV_TIMER11",
    "TISCI_DEV_TIMER2",
    "TISCI_DEV_TIMER3",
    "TISCI_DEV_TIMER4",
    "TISCI_DEV_TIMER5",
    "TISCI_DEV_TIMER6",
    "TISCI_DEV_TIMER7",
    "TISCI_DEV_TIMER8",
    "TISCI_DEV_TIMER9",
    "TISCI_DEV_MCU_TIMER0",
    "TISCI_DEV_MCU_TIMER1",
    "TISCI_DEV_MCU_TIMER2",
    "TISCI_DEV_MCU_TIMER3",
    "TISCI_DEV_ECAP0",
    "TISCI_DEV_EHRPWM0",
    "TISCI_DEV_EHRPWM1",
    "TISCI_DEV_EHRPWM2",
    "TISCI_DEV_EHRPWM3",
    "TISCI_DEV_EHRPWM4",
    "TISCI_DEV_EHRPWM5",
    "TISCI_DEV_ELM0",
    "TISCI_DEV_MMCSD0",
    "TISCI_DEV_MMCSD1",
    "TISCI_DEV_EQEP0",
    "TISCI_DEV_EQEP1",
    "TISCI_DEV_EQEP2",
    "TISCI_DEV_ESM0",
    "TISCI_DEV_MCU_ESM0",
    "TISCI_DEV_WKUP_ESM0",
    "TISCI_DEV_GIC0",
    "TISCI_DEV_GPIO0",
    "TISCI_DEV_GPIO1",
    "TISCI_DEV_WKUP_GPIO0",
    "TISCI_DEV_GPMC0",
    "TISCI_DEV_GTC0",
    "TISCI_DEV_PRU_ICSSG0",
    "TISCI_DEV_PRU_ICSSG1",
    "TISCI_DEV_PRU_ICSSG2",
    "TISCI_DEV_GPU0",
    "TISCI_DEV_CCDEBUGSS0",
    "TISCI_DEV_DSS0",
    "TISCI_DEV_DEBUGSS0",
    "TISCI_DEV_EFUSE0",
    "TISCI_DEV_PSC0",
    "TISCI_DEV_MCU_DEBUGSS0",
    "TISCI_DEV_MCU_EFUSE0",
    "TISCI_DEV_PBIST0",
    "TISCI_DEV_PBIST1",
    "TISCI_DEV_MCU_PBIST0",
    "TISCI_DEV_PLLCTRL0",
    "TISCI_DEV_WKUP_PLLCTRL0",
    "TISCI_DEV_MCU_ROM0",
    "TISCI_DEV_WKUP_PSC0",
    "TISCI_DEV_WKUP_VTM0",
    "TISCI_DEV_DEBUGSUSPENDRTR0",
    "TISCI_DEV_CBASS0",
    "TISCI_DEV_CBASS_DEBUG0",
    "TISCI_DEV_CBASS_FW0",
    "TISCI_DEV_CBASS_INFRA0",
    "TISCI_DEV_ECC_AGGR0",
    "TISCI_DEV_ECC_AGGR1",
    "TISCI_DEV_ECC_AGGR2",
    "TISCI_DEV_MCU_CBASS0",
    "TISCI_DEV_MCU_CBASS_DEBUG0",
    "TISCI_DEV_MCU_CBASS_FW0",
    "TISCI_DEV_MCU_ECC_AGGR0",
    "TISCI_DEV_MCU_ECC_AGGR1",
    "TISCI_DEV_WKUP_CBASS0",
    "TISCI_DEV_WKUP_ECC_AGGR0",
    "TISCI_DEV_WKUP_CBASS_FW0",
    "TISCI_DEV_MAIN2MCU_LVL_INTRTR0",
    "TISCI_DEV_MAIN2MCU_PLS_INTRTR0",
    "TISCI_DEV_CTRL_MMR0",
    "TISCI_DEV_GPIOMUX_INTRTR0",
    "TISCI_DEV_PLL_MMR0",
    "TISCI_DEV_MCU_MCAN0",
    "TISCI_DEV_MCU_MCAN1",
    "TISCI_DEV_MCASP0",
    "TISCI_DEV_MCASP1",
    "TISCI_DEV_MCASP2",
    "TISCI_DEV_MCU_CTRL_MMR0",
    "TISCI_DEV_MCU_PLL_MMR0",
    "TISCI_DEV_MCU_SEC_MMR0",
    "TISCI_DEV_I2C0",
    "TISCI_DEV_I2C1",
    "TISCI_DEV_I2C2",
    "TISCI_DEV_I2C3",
    "TISCI_DEV_MCU_I2C0",
    "TISCI_DEV_WKUP_I2C0",
    "TISCI_DEV_MCU_MSRAM0",
    "TISCI_DEV_DFTSS0",
    "TISCI_DEV_NAVSS0",
    "TISCI_DEV_MCU_NAVSS0",
    "TISCI_DEV_PCIE0",
    "TISCI_DEV_PCIE1",
    "TISCI_DEV_PDMA_DEBUG0",
    "TISCI_DEV_PDMA0",
    "TISCI_DEV_PDMA1",
    "TISCI_DEV_MCU_PDMA0",
    "TISCI_DEV_MCU_PDMA1",
    "TISCI_DEV_MCU_PSRAM0",
    "TISCI_DEV_PSRAMECC0",
    "TISCI_DEV_MCU_ARMSS0",
    "TISCI_DEV_RTI0",
    "TISCI_DEV_RTI1",
    "TISCI_DEV_RTI2",
    "TISCI_DEV_RTI3",
    "TISCI_DEV_MCU_RTI0",
    "TISCI_DEV_MCU_RTI1",
    "TISCI_DEV_SA2_UL0",
    "TISCI_DEV_MCSPI0",
    "TISCI_DEV_MCSPI1",
    "TISCI_DEV_MCSPI2",
    "TISCI_DEV_MCSPI3",
    "TISCI_DEV_MCSPI4",
    "TISCI_DEV_MCU_MCSPI0",
    "TISCI_DEV_MCU_MCSPI1",
    "TISCI_DEV_MCU_MCSPI2",
    "TISCI_DEV_TIMESYNC_INTRTR0",
    "TISCI_DEV_UART1",
    "TISCI_DEV_UART2",
    "TISCI_DEV_USB3SS0",
    "TISCI_DEV_USB3SS1",
    "TISCI_DEV_SERDES0",
    "TISCI_DEV_SERDES1",
    "TISCI_DEV_WKUP_CTRL_MMR0",
    "TISCI_DEV_WKUP_GPIOMUX_INTRTR0",
    "TISCI_DEV_BOARD0",
    "TISCI_DEV_MCU_ARMSS0_CPU0",
    "TISCI_DEV_WKUP_DMSC0_CORTEX_M3_0",
    "TISCI_DEV_NAVSS0_CPTS0",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER0",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER1",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER2",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER3",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER4",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER5",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER6",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER7",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER8",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER9",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER10",
    "TISCI_DEV_NAVSS0_MAILBOX0_CLUSTER11",
    "TISCI_DEV_NAVSS0_MCRC0",
    "TISCI_DEV_NAVSS0_PVU0",
    "TISCI_DEV_NAVSS0_PVU1",
    "TISCI_DEV_NAVSS0_UDMASS_INTA0",
    "TISCI_DEV_NAVSS0_MODSS_INTA0",
    "TISCI_DEV_NAVSS0_MODSS_INTA1",
    "TISCI_DEV_NAVSS0_INTR_ROUTER_0",
    "TISCI_DEV_NAVSS0_TIMER_MGR0",
    "TISCI_DEV_NAVSS0_TIMER_MGR1",
    "TISCI_DEV_NAVSS0_PROXY0",
    "TISCI_DEV_NAVSS0_RINGACC0",
    "TISCI_DEV_NAVSS0_UDMAP0",
    "TISCI_DEV_MCU_NAVSS0_INTR_AGGR_0",
    "TISCI_DEV_MCU_NAVSS0_INTR_ROUTER_0",
    "TISCI_DEV_MCU_NAVSS0_PROXY0",
    "TISCI_DEV_MCU_NAVSS0_MCRC0",
    "TISCI_DEV_MCU_NAVSS0_UDMAP0",
    "TISCI_DEV_MCU_NAVSS0_RINGACC0",
    "TISCI_DEV_COMPUTE_CLUSTER_MSMC0",
    "TISCI_DEV_COMPUTE_CLUSTER_PBIST0",
    "TISCI_DEV_COMPUTE_CLUSTER_CPAC0",
    "TISCI_DEV_COMPUTE_CLUSTER_CPAC_PBIST0",
    "TISCI_DEV_COMPUTE_CLUSTER_CPAC1",
    "TISCI_DEV_COMPUTE_CLUSTER_CPAC_PBIST1",
    "TISCI_DEV_COMPUTE_CLUSTER_A53_0",
    "TISCI_DEV_COMPUTE_CLUSTER_A53_1",
    "TISCI_DEV_COMPUTE_CLUSTER_A53_2",
    "TISCI_DEV_COMPUTE_CLUSTER_A53_3",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_NAVSRAMLO_4",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MCU_FSS_S1_3",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MCU_EXPORT_SLV_0",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_NAVSRAMHI_3",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MCU_SRAM_SLV_1",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_NAVDDRHI_5",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_NAVDDRLO_6",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_CAL0_0",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MAIN_DSS_2",
    "TISCI_DEV_CPT2_PROBE_VBUSM_MCU_FSS_S0_2",
    "TISCI_DEV_OLDI_TX_CORE_MAIN_0",
    "TISCI_DEV_K3_ARM_ATB_FUNNEL_3_32_MCU_0",
    "TISCI_DEV_ICEMELTER_WKUP_0",
    "TISCI_DEV_K3_LED_MAIN_0",
    "TISCI_DEV_VDC_DATA_VBUSM_32B_REF_WKUP2MCU",
    "TISCI_DEV_VDC_DATA_VBUSM_32B_REF_MCU2WKUP",
    "TISCI_DEV_VDC_DATA_VBUSM_64B_REF_MAIN2MCU",
    "TISCI_DEV_VDC_DATA_VBUSM_64B_REF_MCU2MAIN",
    "TISCI_DEV_VDC_DMSC_DBG_VBUSP_32B_REF_DBG2DMSC",
    "TISCI_DEV_VDC_INFRA_VBUSP_32B_REF_WKUP2MAIN_INFRA",
    "TISCI_DEV_VDC_INFRA_VBUSP_32B_REF_MCU2MAIN_INFRA",
    "TISCI_DEV_VDC_SOC_FW_VBUSP_32B_REF_FWWKUP2MCU",
    "TISCI_DEV_VDC_SOC_FW_VBUSP_32B_REF_FWMCU2MAIN",
    "TISCI_DEV_VDC_MCU_DBG_VBUSP_32B_REF_DBGMAIN2MCU",
    "TISCI_DEV_VDC_NAV_PSIL_128B_REF_MAIN2MCU",
    "TISCI_DEV_GS80PRG_SOC_WRAP_WKUP_0",
    "TISCI_DEV_GS80PRG_MCU_WRAP_WKUP_0",
    "TISCI_DEV_MX_WAKEUP_RESET_SYNC_WKUP_0",
    "TISCI_DEV_MX_EFUSE_MAIN_CHAIN_MAIN_0",
    "TISCI_DEV_MX_EFUSE_MCU_CHAIN_MCU_0",
    "TISCI_DEV_DUMMY_IP_LPSC_WKUP2MCU",
    "TISCI_DEV_DUMMY_IP_LPSC_WKUP2MAIN_INFRA",
    "TISCI_DEV_DUMMY_IP_LPSC_DEBUG2DMSC_VD",
    "TISCI_DEV_DUMMY_IP_LPSC_DMSC_VD",
    "TISCI_DEV_DUMMY_IP_LPSC_MCU2MAIN_INFRA",
    "TISCI_DEV_DUMMY_IP_LPSC_MCU2MAIN",
    "TISCI_DEV_DUMMY_IP_LPSC_MCU2WKUP",
    "TISCI_DEV_DUMMY_IP_LPSC_MAIN2MCU",
    "TISCI_DEV_DUMMY_IP_LPSC_EMIF_DATA",
    "TISCI_DEV_MCU_ARMSS0_CPU1"
};
#endif

#if defined (SOC_J721E)
uint32_t gModuleNum[] = {
    TISCI_DEV_MCU_ADC0,
TISCI_DEV_MCU_ADC1,
TISCI_DEV_ATL0,
TISCI_DEV_COMPUTE_CLUSTER_J7ES_TB_VDC_MAIN_0,
TISCI_DEV_A72SS0,
TISCI_DEV_COMPUTE_CLUSTER0_CFG_WRAP,
TISCI_DEV_COMPUTE_CLUSTER0_CLEC,
TISCI_DEV_COMPUTE_CLUSTER0_CORE_CORE,
TISCI_DEV_COMPUTE_CLUSTER0_DDR32SS_EMIF0_EW,
TISCI_DEV_COMPUTE_CLUSTER0_DEBUG_WRAP,
TISCI_DEV_COMPUTE_CLUSTER0_DIVH2_DIVH0,
TISCI_DEV_COMPUTE_CLUSTER0_DIVP_TFT0,
TISCI_DEV_COMPUTE_CLUSTER0_DMSC_WRAP,
TISCI_DEV_COMPUTE_CLUSTER0_EN_MSMC_DOMAIN,
TISCI_DEV_COMPUTE_CLUSTER0_GIC500SS,
TISCI_DEV_C71SS0,
TISCI_DEV_C71SS0_MMA,
TISCI_DEV_COMPUTE_CLUSTER0_PBIST_WRAP,
TISCI_DEV_MCU_CPSW0,
TISCI_DEV_CPSW0,
TISCI_DEV_CPT2_AGGR0,
TISCI_DEV_CPT2_AGGR1,
TISCI_DEV_DMSC_WKUP_0,
TISCI_DEV_CPT2_AGGR2,
TISCI_DEV_MCU_CPT2_AGGR0,
TISCI_DEV_CSI_PSILSS0,
TISCI_DEV_CSI_RX_IF0,
TISCI_DEV_CSI_RX_IF1,
TISCI_DEV_CSI_TX_IF0,
TISCI_DEV_STM0,
TISCI_DEV_DCC0,
TISCI_DEV_DCC1,
TISCI_DEV_DCC2,
TISCI_DEV_DCC3,
TISCI_DEV_DCC4,
TISCI_DEV_MCU_TIMER0,
TISCI_DEV_DCC5,
TISCI_DEV_DCC6,
TISCI_DEV_DCC7,
TISCI_DEV_DCC8,
TISCI_DEV_DCC9,
TISCI_DEV_DCC10,
TISCI_DEV_DCC11,
TISCI_DEV_DCC12,
TISCI_DEV_MCU_DCC0,
TISCI_DEV_MCU_DCC1,
TISCI_DEV_MCU_DCC2,
TISCI_DEV_DDR0,
TISCI_DEV_DMPAC_TOP_MAIN_0,
TISCI_DEV_TIMER0,
TISCI_DEV_TIMER1,
TISCI_DEV_TIMER2,
TISCI_DEV_TIMER3,
TISCI_DEV_TIMER4,
TISCI_DEV_TIMER5,
TISCI_DEV_TIMER6,
TISCI_DEV_TIMER7,
TISCI_DEV_TIMER8,
TISCI_DEV_TIMER9,
TISCI_DEV_TIMER10,
TISCI_DEV_GTC0,
TISCI_DEV_TIMER11,
TISCI_DEV_TIMER12,
TISCI_DEV_TIMER13,
TISCI_DEV_TIMER14,
TISCI_DEV_TIMER15,
TISCI_DEV_TIMER16,
TISCI_DEV_TIMER17,
TISCI_DEV_TIMER18,
TISCI_DEV_TIMER19,
TISCI_DEV_MCU_TIMER1,
TISCI_DEV_MCU_TIMER2,
TISCI_DEV_MCU_TIMER3,
TISCI_DEV_MCU_TIMER4,
TISCI_DEV_MCU_TIMER5,
TISCI_DEV_MCU_TIMER6,
TISCI_DEV_MCU_TIMER7,
TISCI_DEV_MCU_TIMER8,
TISCI_DEV_MCU_TIMER9,
TISCI_DEV_ECAP0,
TISCI_DEV_ECAP1,
TISCI_DEV_ECAP2,
TISCI_DEV_EHRPWM0,
TISCI_DEV_EHRPWM1,
TISCI_DEV_EHRPWM2,
TISCI_DEV_EHRPWM3,
TISCI_DEV_EHRPWM4,
TISCI_DEV_EHRPWM5,
TISCI_DEV_ELM0,
TISCI_DEV_EMIF_DATA_0_VD,
TISCI_DEV_MMCSD0,
TISCI_DEV_MMCSD1,
TISCI_DEV_MMCSD2,
TISCI_DEV_EQEP0,
TISCI_DEV_EQEP1,
TISCI_DEV_EQEP2,
TISCI_DEV_ESM0,
TISCI_DEV_MCU_ESM0,
TISCI_DEV_WKUP_ESM0,
TISCI_DEV_FSS_MCU_0,
TISCI_DEV_MCU_FSS0_FSAS_0,
TISCI_DEV_MCU_FSS0_HYPERBUS1P0_0,
TISCI_DEV_MCU_FSS0_OSPI_0,
TISCI_DEV_MCU_FSS0_OSPI_1,
TISCI_DEV_GPIO0,
TISCI_DEV_GPIO1,
TISCI_DEV_GPIO2,
TISCI_DEV_GPIO3,
TISCI_DEV_GPIO4,
TISCI_DEV_GPIO5,
TISCI_DEV_GPIO6,
TISCI_DEV_GPIO7,
TISCI_DEV_WKUP_GPIO0,
TISCI_DEV_WKUP_GPIO1,
TISCI_DEV_GPMC0,
TISCI_DEV_I3C0,
TISCI_DEV_MCU_I3C0,
TISCI_DEV_MCU_I3C1,
TISCI_DEV_PRU_ICSSG0,
TISCI_DEV_PRU_ICSSG1,
TISCI_DEV_C66SS0_INTROUTER0,
TISCI_DEV_C66SS1_INTROUTER0,
TISCI_DEV_CMPEVENT_INTRTR0,
TISCI_DEV_J7_LASCAR_GPU_WRAP_MAIN_0,
TISCI_DEV_GPU0_GPU_0,
TISCI_DEV_GPU0_GPUCORE_0,
TISCI_DEV_LED0,
TISCI_DEV_MAIN2MCU_LVL_INTRTR0,
TISCI_DEV_MAIN2MCU_PLS_INTRTR0,
TISCI_DEV_GPIOMUX_INTRTR0,
TISCI_DEV_WKUP_PORZ_SYNC0,
TISCI_DEV_PSC0,
TISCI_DEV_R5FSS0_INTROUTER0,
TISCI_DEV_R5FSS1_INTROUTER0,
TISCI_DEV_TIMESYNC_INTRTR0,
TISCI_DEV_WKUP_GPIOMUX_INTRTR0,
TISCI_DEV_WKUP_PSC0,
TISCI_DEV_AASRC0,
TISCI_DEV_K3_C66_COREPAC_MAIN_0,
TISCI_DEV_K3_C66_COREPAC_MAIN_1,
TISCI_DEV_C66SS0_CORE0,
TISCI_DEV_C66SS1_CORE0,
TISCI_DEV_DECODER0,
TISCI_DEV_WKUP_DDPA0,
TISCI_DEV_UART0,
TISCI_DEV_DPHY_RX0,
TISCI_DEV_DPHY_RX1,
TISCI_DEV_MCU_UART0,
TISCI_DEV_DSS_DSI0,
TISCI_DEV_DSS_EDP0,
TISCI_DEV_DSS0,
TISCI_DEV_ENCODER0,
TISCI_DEV_WKUP_VTM0,
TISCI_DEV_MAIN2WKUPMCU_VD,
TISCI_DEV_MCAN0,
TISCI_DEV_BOARD0,
TISCI_DEV_MCAN1,
TISCI_DEV_MCAN2,
TISCI_DEV_MCAN3,
TISCI_DEV_MCAN4,
TISCI_DEV_MCAN5,
TISCI_DEV_MCAN6,
TISCI_DEV_MCAN7,
TISCI_DEV_MCAN8,
TISCI_DEV_MCAN9,
TISCI_DEV_MCAN10,
TISCI_DEV_MCAN11,
TISCI_DEV_MCAN12,
TISCI_DEV_MCAN13,
TISCI_DEV_MCU_MCAN0,
TISCI_DEV_MCU_MCAN1,
TISCI_DEV_MCASP0,
TISCI_DEV_MCASP1,
TISCI_DEV_MCASP2,
TISCI_DEV_MCASP3,
TISCI_DEV_MCASP4,
TISCI_DEV_MCASP5,
TISCI_DEV_MCASP6,
TISCI_DEV_MCASP7,
TISCI_DEV_MCASP8,
TISCI_DEV_MCASP9,
TISCI_DEV_MCASP10,
TISCI_DEV_MCASP11,
TISCI_DEV_MLB0,
TISCI_DEV_I2C0,
TISCI_DEV_I2C1,
TISCI_DEV_I2C2,
TISCI_DEV_I2C3,
TISCI_DEV_I2C4,
TISCI_DEV_I2C5,
TISCI_DEV_I2C6,
TISCI_DEV_MCU_I2C0,
TISCI_DEV_MCU_I2C1,
TISCI_DEV_WKUP_I2C0,
TISCI_DEV_NAVSS0,
TISCI_DEV_NAVSS0_CPTS_0,
TISCI_DEV_A72SS0_CORE0,
TISCI_DEV_A72SS0_CORE1,
TISCI_DEV_NAVSS0_DTI_0,
TISCI_DEV_NAVSS0_MODSS_INTAGGR_0,
TISCI_DEV_NAVSS0_MODSS_INTAGGR_1,
TISCI_DEV_NAVSS0_UDMASS_INTAGGR_0,
TISCI_DEV_NAVSS0_PROXY_0,
TISCI_DEV_NAVSS0_RINGACC0,
TISCI_DEV_NAVSS0_UDMAP0,
TISCI_DEV_NAVSS0_INTR_ROUTER_0,
TISCI_DEV_NAVSS0_MAILBOX_0,
TISCI_DEV_NAVSS0_MAILBOX_1,
TISCI_DEV_NAVSS0_MAILBOX_2,
TISCI_DEV_NAVSS0_MAILBOX_3,
TISCI_DEV_NAVSS0_MAILBOX_4,
TISCI_DEV_NAVSS0_MAILBOX_5,
TISCI_DEV_NAVSS0_MAILBOX_6,
TISCI_DEV_NAVSS0_MAILBOX_7,
TISCI_DEV_NAVSS0_MAILBOX_8,
TISCI_DEV_NAVSS0_MAILBOX_9,
TISCI_DEV_NAVSS0_MAILBOX_10,
TISCI_DEV_NAVSS0_MAILBOX_11,
TISCI_DEV_NAVSS0_SPINLOCK_0,
TISCI_DEV_NAVSS0_MCRC_0,
TISCI_DEV_NAVSS0_TBU_0,
TISCI_DEV_NAVSS0_TCU_0,
TISCI_DEV_NAVSS0_TIMERMGR_0,
TISCI_DEV_NAVSS0_TIMERMGR_1,
TISCI_DEV_MCU_NAVSS0,
TISCI_DEV_MCU_NAVSS0_INTAGGR_0,
TISCI_DEV_MCU_NAVSS0_PROXY_0,
TISCI_DEV_MCU_NAVSS0_RINGACC0,
TISCI_DEV_MCU_NAVSS0_UDMAP0,
TISCI_DEV_MCU_NAVSS0_INTR_ROUTER_0,
TISCI_DEV_MCU_NAVSS0_MCRC_0,
TISCI_DEV_PCIE0,
TISCI_DEV_PCIE1,
TISCI_DEV_PCIE2,
TISCI_DEV_PCIE3,
TISCI_DEV_PULSAR_SL_MAIN_0,
TISCI_DEV_PULSAR_SL_MAIN_1,
TISCI_DEV_R5FSS0_CORE0,
TISCI_DEV_R5FSS0_CORE1,
TISCI_DEV_R5FSS1_CORE0,
TISCI_DEV_R5FSS1_CORE1,
TISCI_DEV_PULSAR_SL_MCU_0,
TISCI_DEV_MCU_R5FSS0_CORE0,
TISCI_DEV_MCU_R5FSS0_CORE1,
TISCI_DEV_RTI0,
TISCI_DEV_RTI1,
TISCI_DEV_RTI24,
TISCI_DEV_RTI25,
TISCI_DEV_RTI16,
TISCI_DEV_RTI15,
TISCI_DEV_RTI28,
TISCI_DEV_RTI29,
TISCI_DEV_RTI30,
TISCI_DEV_RTI31,
TISCI_DEV_MCU_RTI0,
TISCI_DEV_MCU_RTI1,
TISCI_DEV_SA2_UL0,
TISCI_DEV_MCU_SA2_UL0,
TISCI_DEV_MCSPI0,
TISCI_DEV_MCSPI1,
TISCI_DEV_MCSPI2,
TISCI_DEV_MCSPI3,
TISCI_DEV_MCSPI4,
TISCI_DEV_MCSPI5,
TISCI_DEV_MCSPI6,
TISCI_DEV_MCSPI7,
TISCI_DEV_MCU_MCSPI0,
TISCI_DEV_MCU_MCSPI1,
TISCI_DEV_MCU_MCSPI2,
TISCI_DEV_UFS0,
TISCI_DEV_UART1,
TISCI_DEV_UART2,
TISCI_DEV_UART3,
TISCI_DEV_UART4,
TISCI_DEV_UART5,
TISCI_DEV_UART6,
TISCI_DEV_UART7,
TISCI_DEV_UART8,
TISCI_DEV_UART9,
TISCI_DEV_WKUP_UART0,
TISCI_DEV_USB0,
TISCI_DEV_USB1,
TISCI_DEV_VPAC_TOP_MAIN_0,
TISCI_DEV_VPFE0,
TISCI_DEV_SERDES_16G0,
TISCI_DEV_SERDES_16G1,
TISCI_DEV_SERDES_16G2,
TISCI_DEV_SERDES_16G3,
TISCI_DEV_DPHY_TX0,
TISCI_DEV_SERDES_10G0,
TISCI_DEV_WKUPMCU2MAIN_VD,
TISCI_DEV_NAVSS0_MODSS,
TISCI_DEV_NAVSS0_UDMASS,
TISCI_DEV_NAVSS0_VIRTSS,
TISCI_DEV_MCU_NAVSS0_MODSS,
TISCI_DEV_MCU_NAVSS0_UDMASS,
TISCI_DEV_DEBUGSS_WRAP0,
TISCI_DEV_DMPAC0_SDE_0
};

char * gModuleNames[] = {
    "TISCI_DEV_MCU_ADC0",
"TISCI_DEV_MCU_ADC1",
"TISCI_DEV_ATL0",
"TISCI_DEV_COMPUTE_CLUSTER_J7ES_TB_VDC_MAIN_0",
"TISCI_DEV_A72SS0",
"TISCI_DEV_COMPUTE_CLUSTER0_CFG_WRAP",
"TISCI_DEV_COMPUTE_CLUSTER0_CLEC",
"TISCI_DEV_COMPUTE_CLUSTER0_CORE_CORE",
"TISCI_DEV_COMPUTE_CLUSTER0_DDR32SS_EMIF0_EW",
"TISCI_DEV_COMPUTE_CLUSTER0_DEBUG_WRAP",
"TISCI_DEV_COMPUTE_CLUSTER0_DIVH2_DIVH0",
"TISCI_DEV_COMPUTE_CLUSTER0_DIVP_TFT0",
"TISCI_DEV_COMPUTE_CLUSTER0_DMSC_WRAP",
"TISCI_DEV_COMPUTE_CLUSTER0_EN_MSMC_DOMAIN",
"TISCI_DEV_COMPUTE_CLUSTER0_GIC500SS",
"TISCI_DEV_C71SS0",
"TISCI_DEV_C71SS0_MMA",
"TISCI_DEV_COMPUTE_CLUSTER0_PBIST_WRAP",
"TISCI_DEV_MCU_CPSW0",
"TISCI_DEV_CPSW0",
"TISCI_DEV_CPT2_AGGR0",
"TISCI_DEV_CPT2_AGGR1",
"TISCI_DEV_DMSC_WKUP_0",
"TISCI_DEV_CPT2_AGGR2",
"TISCI_DEV_MCU_CPT2_AGGR0",
"TISCI_DEV_CSI_PSILSS0",
"TISCI_DEV_CSI_RX_IF0",
"TISCI_DEV_CSI_RX_IF1",
"TISCI_DEV_CSI_TX_IF0",
"TISCI_DEV_STM0",
"TISCI_DEV_DCC0",
"TISCI_DEV_DCC1",
"TISCI_DEV_DCC2",
"TISCI_DEV_DCC3",
"TISCI_DEV_DCC4",
"TISCI_DEV_MCU_TIMER0",
"TISCI_DEV_DCC5",
"TISCI_DEV_DCC6",
"TISCI_DEV_DCC7",
"TISCI_DEV_DCC8",
"TISCI_DEV_DCC9",
"TISCI_DEV_DCC10",
"TISCI_DEV_DCC11",
"TISCI_DEV_DCC12",
"TISCI_DEV_MCU_DCC0",
"TISCI_DEV_MCU_DCC1",
"TISCI_DEV_MCU_DCC2",
"TISCI_DEV_DDR0",
"TISCI_DEV_DMPAC_TOP_MAIN_0",
"TISCI_DEV_TIMER0",
"TISCI_DEV_TIMER1",
"TISCI_DEV_TIMER2",
"TISCI_DEV_TIMER3",
"TISCI_DEV_TIMER4",
"TISCI_DEV_TIMER5",
"TISCI_DEV_TIMER6",
"TISCI_DEV_TIMER7",
"TISCI_DEV_TIMER8",
"TISCI_DEV_TIMER9",
"TISCI_DEV_TIMER10",
"TISCI_DEV_GTC0",
"TISCI_DEV_TIMER11",
"TISCI_DEV_TIMER12",
"TISCI_DEV_TIMER13",
"TISCI_DEV_TIMER14",
"TISCI_DEV_TIMER15",
"TISCI_DEV_TIMER16",
"TISCI_DEV_TIMER17",
"TISCI_DEV_TIMER18",
"TISCI_DEV_TIMER19",
"TISCI_DEV_MCU_TIMER1",
"TISCI_DEV_MCU_TIMER2",
"TISCI_DEV_MCU_TIMER3",
"TISCI_DEV_MCU_TIMER4",
"TISCI_DEV_MCU_TIMER5",
"TISCI_DEV_MCU_TIMER6",
"TISCI_DEV_MCU_TIMER7",
"TISCI_DEV_MCU_TIMER8",
"TISCI_DEV_MCU_TIMER9",
"TISCI_DEV_ECAP0",
"TISCI_DEV_ECAP1",
"TISCI_DEV_ECAP2",
"TISCI_DEV_EHRPWM0",
"TISCI_DEV_EHRPWM1",
"TISCI_DEV_EHRPWM2",
"TISCI_DEV_EHRPWM3",
"TISCI_DEV_EHRPWM4",
"TISCI_DEV_EHRPWM5",
"TISCI_DEV_ELM0",
"TISCI_DEV_EMIF_DATA_0_VD",
"TISCI_DEV_MMCSD0",
"TISCI_DEV_MMCSD1",
"TISCI_DEV_MMCSD2",
"TISCI_DEV_EQEP0",
"TISCI_DEV_EQEP1",
"TISCI_DEV_EQEP2",
"TISCI_DEV_ESM0",
"TISCI_DEV_MCU_ESM0",
"TISCI_DEV_WKUP_ESM0",
"TISCI_DEV_FSS_MCU_0",
"TISCI_DEV_MCU_FSS0_FSAS_0",
"TISCI_DEV_MCU_FSS0_HYPERBUS1P0_0",
"TISCI_DEV_MCU_FSS0_OSPI_0",
"TISCI_DEV_MCU_FSS0_OSPI_1",
"TISCI_DEV_GPIO0",
"TISCI_DEV_GPIO1",
"TISCI_DEV_GPIO2",
"TISCI_DEV_GPIO3",
"TISCI_DEV_GPIO4",
"TISCI_DEV_GPIO5",
"TISCI_DEV_GPIO6",
"TISCI_DEV_GPIO7",
"TISCI_DEV_WKUP_GPIO0",
"TISCI_DEV_WKUP_GPIO1",
"TISCI_DEV_GPMC0",
"TISCI_DEV_I3C0",
"TISCI_DEV_MCU_I3C0",
"TISCI_DEV_MCU_I3C1",
"TISCI_DEV_PRU_ICSSG0",
"TISCI_DEV_PRU_ICSSG1",
"TISCI_DEV_C66SS0_INTROUTER0",
"TISCI_DEV_C66SS1_INTROUTER0",
"TISCI_DEV_CMPEVENT_INTRTR0",
"TISCI_DEV_J7_LASCAR_GPU_WRAP_MAIN_0",
"TISCI_DEV_GPU0_GPU_0",
"TISCI_DEV_GPU0_GPUCORE_0",
"TISCI_DEV_LED0",
"TISCI_DEV_MAIN2MCU_LVL_INTRTR0",
"TISCI_DEV_MAIN2MCU_PLS_INTRTR0",
"TISCI_DEV_GPIOMUX_INTRTR0",
"TISCI_DEV_WKUP_PORZ_SYNC0",
"TISCI_DEV_PSC0",
"TISCI_DEV_R5FSS0_INTROUTER0",
"TISCI_DEV_R5FSS1_INTROUTER0",
"TISCI_DEV_TIMESYNC_INTRTR0",
"TISCI_DEV_WKUP_GPIOMUX_INTRTR0",
"TISCI_DEV_WKUP_PSC0",
"TISCI_DEV_AASRC0",
"TISCI_DEV_K3_C66_COREPAC_MAIN_0",
"TISCI_DEV_K3_C66_COREPAC_MAIN_1",
"TISCI_DEV_C66SS0_CORE0",
"TISCI_DEV_C66SS1_CORE0",
"TISCI_DEV_DECODER0",
"TISCI_DEV_WKUP_DDPA0",
"TISCI_DEV_UART0",
"TISCI_DEV_DPHY_RX0",
"TISCI_DEV_DPHY_RX1",
"TISCI_DEV_MCU_UART0",
"TISCI_DEV_DSS_DSI0",
"TISCI_DEV_DSS_EDP0",
"TISCI_DEV_DSS0",
"TISCI_DEV_ENCODER0",
"TISCI_DEV_WKUP_VTM0",
"TISCI_DEV_MAIN2WKUPMCU_VD",
"TISCI_DEV_MCAN0",
"TISCI_DEV_BOARD0",
"TISCI_DEV_MCAN1",
"TISCI_DEV_MCAN2",
"TISCI_DEV_MCAN3",
"TISCI_DEV_MCAN4",
"TISCI_DEV_MCAN5",
"TISCI_DEV_MCAN6",
"TISCI_DEV_MCAN7",
"TISCI_DEV_MCAN8",
"TISCI_DEV_MCAN9",
"TISCI_DEV_MCAN10",
"TISCI_DEV_MCAN11",
"TISCI_DEV_MCAN12",
"TISCI_DEV_MCAN13",
"TISCI_DEV_MCU_MCAN0",
"TISCI_DEV_MCU_MCAN1",
"TISCI_DEV_MCASP0",
"TISCI_DEV_MCASP1",
"TISCI_DEV_MCASP2",
"TISCI_DEV_MCASP3",
"TISCI_DEV_MCASP4",
"TISCI_DEV_MCASP5",
"TISCI_DEV_MCASP6",
"TISCI_DEV_MCASP7",
"TISCI_DEV_MCASP8",
"TISCI_DEV_MCASP9",
"TISCI_DEV_MCASP10",
"TISCI_DEV_MCASP11",
"TISCI_DEV_MLB0",
"TISCI_DEV_I2C0",
"TISCI_DEV_I2C1",
"TISCI_DEV_I2C2",
"TISCI_DEV_I2C3",
"TISCI_DEV_I2C4",
"TISCI_DEV_I2C5",
"TISCI_DEV_I2C6",
"TISCI_DEV_MCU_I2C0",
"TISCI_DEV_MCU_I2C1",
"TISCI_DEV_WKUP_I2C0",
"TISCI_DEV_NAVSS0",
"TISCI_DEV_NAVSS0_CPTS_0",
"TISCI_DEV_A72SS0_CORE0",
"TISCI_DEV_A72SS0_CORE1",
"TISCI_DEV_NAVSS0_DTI_0",
"TISCI_DEV_NAVSS0_MODSS_INTAGGR_0",
"TISCI_DEV_NAVSS0_MODSS_INTAGGR_1",
"TISCI_DEV_NAVSS0_UDMASS_INTAGGR_0",
"TISCI_DEV_NAVSS0_PROXY_0",
"TISCI_DEV_NAVSS0_RINGACC0",
"TISCI_DEV_NAVSS0_UDMAP0",
"TISCI_DEV_NAVSS0_INTR_ROUTER_0",
"TISCI_DEV_NAVSS0_MAILBOX_0",
"TISCI_DEV_NAVSS0_MAILBOX_1",
"TISCI_DEV_NAVSS0_MAILBOX_2",
"TISCI_DEV_NAVSS0_MAILBOX_3",
"TISCI_DEV_NAVSS0_MAILBOX_4",
"TISCI_DEV_NAVSS0_MAILBOX_5",
"TISCI_DEV_NAVSS0_MAILBOX_6",
"TISCI_DEV_NAVSS0_MAILBOX_7",
"TISCI_DEV_NAVSS0_MAILBOX_8",
"TISCI_DEV_NAVSS0_MAILBOX_9",
"TISCI_DEV_NAVSS0_MAILBOX_10",
"TISCI_DEV_NAVSS0_MAILBOX_11",
"TISCI_DEV_NAVSS0_SPINLOCK_0",
"TISCI_DEV_NAVSS0_MCRC_0",
"TISCI_DEV_NAVSS0_TBU_0",
"TISCI_DEV_NAVSS0_TCU_0",
"TISCI_DEV_NAVSS0_TIMERMGR_0",
"TISCI_DEV_NAVSS0_TIMERMGR_1",
"TISCI_DEV_MCU_NAVSS0",
"TISCI_DEV_MCU_NAVSS0_INTAGGR_0",
"TISCI_DEV_MCU_NAVSS0_PROXY_0",
"TISCI_DEV_MCU_NAVSS0_RINGACC0",
"TISCI_DEV_MCU_NAVSS0_UDMAP0",
"TISCI_DEV_MCU_NAVSS0_INTR_ROUTER_0",
"TISCI_DEV_MCU_NAVSS0_MCRC_0",
"TISCI_DEV_PCIE0",
"TISCI_DEV_PCIE1",
"TISCI_DEV_PCIE2",
"TISCI_DEV_PCIE3",
"TISCI_DEV_PULSAR_SL_MAIN_0",
"TISCI_DEV_PULSAR_SL_MAIN_1",
"TISCI_DEV_R5FSS0_CORE0",
"TISCI_DEV_R5FSS0_CORE1",
"TISCI_DEV_R5FSS1_CORE0",
"TISCI_DEV_R5FSS1_CORE1",
"TISCI_DEV_PULSAR_SL_MCU_0",
"TISCI_DEV_MCU_R5FSS0_CORE0",
"TISCI_DEV_MCU_R5FSS0_CORE1",
"TISCI_DEV_RTI0",
"TISCI_DEV_RTI1",
"TISCI_DEV_RTI24",
"TISCI_DEV_RTI25",
"TISCI_DEV_RTI16",
"TISCI_DEV_RTI15",
"TISCI_DEV_RTI28",
"TISCI_DEV_RTI29",
"TISCI_DEV_RTI30",
"TISCI_DEV_RTI31",
"TISCI_DEV_MCU_RTI0",
"TISCI_DEV_MCU_RTI1",
"TISCI_DEV_SA2_UL0",
"TISCI_DEV_MCU_SA2_UL0",
"TISCI_DEV_MCSPI0",
"TISCI_DEV_MCSPI1",
"TISCI_DEV_MCSPI2",
"TISCI_DEV_MCSPI3",
"TISCI_DEV_MCSPI4",
"TISCI_DEV_MCSPI5",
"TISCI_DEV_MCSPI6",
"TISCI_DEV_MCSPI7",
"TISCI_DEV_MCU_MCSPI0",
"TISCI_DEV_MCU_MCSPI1",
"TISCI_DEV_MCU_MCSPI2",
"TISCI_DEV_UFS0",
"TISCI_DEV_UART1",
"TISCI_DEV_UART2",
"TISCI_DEV_UART3",
"TISCI_DEV_UART4",
"TISCI_DEV_UART5",
"TISCI_DEV_UART6",
"TISCI_DEV_UART7",
"TISCI_DEV_UART8",
"TISCI_DEV_UART9",
"TISCI_DEV_WKUP_UART0",
"TISCI_DEV_USB0",
"TISCI_DEV_USB1",
"TISCI_DEV_VPAC_TOP_MAIN_0",
"TISCI_DEV_VPFE0",
"TISCI_DEV_SERDES_16G0",
"TISCI_DEV_SERDES_16G1",
"TISCI_DEV_SERDES_16G2",
"TISCI_DEV_SERDES_16G3",
"TISCI_DEV_DPHY_TX0",
"TISCI_DEV_SERDES_10G0",
"TISCI_DEV_WKUPMCU2MAIN_VD",
"TISCI_DEV_NAVSS0_MODSS",
"TISCI_DEV_NAVSS0_UDMASS",
"TISCI_DEV_NAVSS0_VIRTSS",
"TISCI_DEV_MCU_NAVSS0_MODSS",
"TISCI_DEV_MCU_NAVSS0_UDMASS",
"TISCI_DEV_DEBUGSS_WRAP0",
"TISCI_DEV_DMPAC0_SDE_0"
};

#endif

/* ========================================================================== */
/*                          Function Definitions                              */
/* ========================================================================== */

int32_t main(void)
{
    int32_t         status = PM_SUCCESS;
    uint32_t            idx = 0U;
    AppUtils_defaultInit();
    App_printf("\nPM System Config Test App\n");
    status = Sciclient_init(NULL);
    if (status == PM_SUCCESS)
    {
        /* Function to Test System Config */
        /* Enable Modules */
        App_printf("\n---------------------------------------------------");
        App_printf("\nALWAYS ENABLED CONFIGURATION\n");
        App_printf("---------------------------------------------------\n");
        alwaysEnabledConfig();
        App_printf("---------------------------------------------------\n");
        App_printf("\nALWAYS DISABLED CONFIGURATION\n");
        App_printf("---------------------------------------------------\n");
        alwaysDisabledConfig();
        App_printf("\n---------------------------------------------------");
        App_printf("\nRETENTION CONFIGURATION\n");
        App_printf("---------------------------------------------------\n");
        retentionConfig();
        App_printf("---------------------------------------------------\n");

        App_printf("\n---------------------------------------------------");
        App_printf("\nGET SYSCONFIG TEST\n");
        App_printf("---------------------------------------------------\n");
        for (idx = 0; idx < sizeof(gModuleNum)/sizeof(uint32_t); idx++)
        {
            pmlibSysConfigPowerState_t    currState;
            pmlibSysConfigDetailedState_t detailedState;
            status   = PMLIBSysConfigGetPowerState(gModuleNum[idx],
                                                   &currState,
                                                   &detailedState);
            App_printf("%s", (char *) gModuleNames[idx]);
            App_printf(": ");
            if (PM_SUCCESS == status)
            {
                if (PMLIB_SYS_CONFIG_INTRANSITION == currState)
                {
                    App_printf(" PMLIB_SYS_CONFIG_INTRANSITION\n");
                }
                else if (PMLIB_SYS_CONFIG_DISABLED == currState)
                {
                    App_printf(" PMLIB_SYS_CONFIG_DISABLED\n");
                }
                else if (PMLIB_SYS_CONFIG_RETENTION == currState)
                {
                    App_printf(" PMLIB_SYS_CONFIG_RETENTION\n");
                }
                else if (PMLIB_SYS_CONFIG_ALWAYS_ENABLED == currState)
                {
                    App_printf(" PMLIB_SYS_CONFIG_ALWAYS_ENABLED\n");
                }
            }
            else
            {
                App_printf(" FAIL: API Returned Error. Error Code = %d\n", status);
                finalSuccess = PM_FAIL;
            }
        }
    }
    App_printf("---------------------------------------------------\n");
    if (PM_SUCCESS == finalSuccess)
    {
        App_printf("All tests have passed.\n");
    }
    else
    {
        App_printf("Some tests have failed.\n");
    }
    return 0;
}

void alwaysEnabledConfig(void)
{
    pmlibSysConfigPowerStateParams_t inputTable;
    pmlibSysConfigErrReturn_t        resultReturn;
    uint32_t idx;
    pmlibSysConfigPowerState_t       pwrSt;
    int32_t status = PM_SUCCESS;
    pwrSt = PMLIB_SYS_CONFIG_ALWAYS_ENABLED;
    for (idx = 0U; idx < sizeof(gModuleNum)/sizeof(uint32_t); idx++)
    {
        PMLIBSysConfigPowerStateParams_init(&inputTable, (uint32_t) 1U);
        inputTable.modId    = gModuleNum[idx];
        inputTable.pwrState = pwrSt;
        App_printf("%s", (char *) gModuleNames[idx]);
        App_printf(": ");
        status   = PMLIBSysConfigSetPowerState(&inputTable, (uint32_t) 1U,
                                               PM_TIMEOUT_INFINITE,
                                               &resultReturn);
        if (PM_SUCCESS == status)
        {
            App_printf("PASS\n");
        }
        else
        {
            if (PM_SYS_CONFIG_MODULE_CANNOT_BE_ENABLED ==
                resultReturn.failCause)
            {
                App_printf(
                    "No Valid Module Mode, Cannot be enabled from software\n");
                App_printf("Optional Clocks if any have been enabled\n");
            }
            else
            {
                App_printf(
                    "PMLIB_SYS_CONFIG_ALWAYS_ENABLED FAIL :Error Code Returned : %d\n", resultReturn.failCause);
                finalSuccess = PM_FAIL;
            }
        }
    }
}
void alwaysDisabledConfig(void)
{
    pmlibSysConfigPowerStateParams_t inputTable;
    pmlibSysConfigErrReturn_t        resultReturn;
    uint32_t idx;
    pmlibSysConfigPowerState_t       pwrSt;
    int32_t status = PM_SUCCESS;
    pwrSt = PMLIB_SYS_CONFIG_DISABLED;
    for (idx = 0U; idx < sizeof(gModuleNum)/sizeof(uint32_t); idx++)
    {
#if defined (SOC_AM65XX)
        if ((TISCI_DEV_MCU_NAVSS0 == gModuleNum[idx]) ||
            (TISCI_DEV_NAVSS0 == gModuleNum[idx]) ||
#if defined (BUILD_MPU1_0)
            (TISCI_DEV_RTI0 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI1 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI2 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI3 == gModuleNum[idx]) ||
            (TISCI_DEV_COMPUTE_CLUSTER_A53_0 == gModuleNum[idx]) ||
            (TISCI_DEV_COMPUTE_CLUSTER_A53_1 == gModuleNum[idx]) ||
            (TISCI_DEV_COMPUTE_CLUSTER_A53_2 == gModuleNum[idx]) ||
            (TISCI_DEV_COMPUTE_CLUSTER_A53_3 == gModuleNum[idx]) ||
#endif
            (TISCI_DEV_MCU_RTI0 == gModuleNum[idx]) ||
            (TISCI_DEV_MCU_RTI1 == gModuleNum[idx]) ||
            (TISCI_DEV_WKUP_UART0 == gModuleNum[idx]) ||
            (TISCI_DEV_DUMMY_IP_LPSC_DEBUG2DMSC_VD == gModuleNum[idx]) ||
            (TISCI_DEV_DUMMY_IP_LPSC_DMSC_VD == gModuleNum[idx]))
        {
            continue;
        }
#endif
#if defined (SOC_J721E)
        if ((TISCI_DEV_MCU_NAVSS0 == gModuleNum[idx]) ||
            (TISCI_DEV_NAVSS0 == gModuleNum[idx]) ||
            (TISCI_DEV_EMIF_DATA_0_VD == gModuleNum[idx]) ||
            (TISCI_DEV_DDR0 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI0  == gModuleNum[idx]) ||
            (TISCI_DEV_RTI1  == gModuleNum[idx]) ||
            (TISCI_DEV_RTI24 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI25 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI16 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI15 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI28 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI29 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI30 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI31 == gModuleNum[idx]) ||
        #if defined(BUILD_MCU1_0) || defined(BUILD_MCU1_1)
            (TISCI_DEV_MCU_R5FSS0_CORE1 == gModuleNum[idx]) ||
            (TISCI_DEV_MCU_R5FSS0_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MCU_0 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_MPU1_0)
            (TISCI_DEV_A72SS0_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_A72SS0_CORE1 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_MCU2_0)
            (TISCI_DEV_R5FSS0_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MAIN_0 == gModuleNum[idx]) ||
            (TISCI_DEV_TIMER14 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_MCU2_1)
            (TISCI_DEV_R5FSS0_CORE1 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MAIN_1 == gModuleNum[idx]) || 
        #endif
        #if defined (BUILD_MCU3_0)
            (TISCI_DEV_R5FSS1_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MAIN_0 == gModuleNum[idx]) || 
        #endif
        #if defined (BUILD_MCU3_1)
            (TISCI_DEV_R5FSS1_CORE1 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MAIN_1 == gModuleNum[idx]) || 
        #endif
        #if defined (BUILD_C66X_1)
            (TISCI_DEV_C66SS0_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_C66SS0_INTROUTER0 == gModuleNum[idx]) ||
            (TISCI_DEV_K3_C66_COREPAC_MAIN_0 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_C66X_2)
            (TISCI_DEV_C66SS1_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_C66SS1_INTROUTER0 == gModuleNum[idx]) ||
            (TISCI_DEV_K3_C66_COREPAC_MAIN_1 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_C7X_1)
            (TISCI_DEV_C71SS0 == gModuleNum[idx]) ||
            (TISCI_DEV_C71SS0_MMA == gModuleNum[idx]) ||
        #endif
            (TISCI_DEV_MCU_RTI0 == gModuleNum[idx]) ||
            (TISCI_DEV_MCU_RTI1 == gModuleNum[idx]) ||
            (TISCI_DEV_WKUP_UART0 == gModuleNum[idx]) ||
            (TISCI_DEV_UART9 == gModuleNum[idx]) ||
            (TISCI_DEV_DMSC_WKUP_0 == gModuleNum[idx]))
        {
            continue;
        }
#endif
        PMLIBSysConfigPowerStateParams_init(&inputTable, (uint32_t) 1U);
        inputTable.modId    = gModuleNum[idx];
        inputTable.pwrState = pwrSt;
        App_printf("%s", (char *) gModuleNames[idx]);
        App_printf(": ");
        status   = PMLIBSysConfigSetPowerState(&inputTable, (uint32_t) 1U,
                                               PM_TIMEOUT_INFINITE,
                                               &resultReturn);
        if (PM_SUCCESS == status)
        {
            App_printf("PASS\n");
        }
        else
        {
            if (PM_SYS_CONFIG_MODULE_CANNOT_BE_DISABLED ==
                resultReturn.failCause)
            {
                App_printf(
                    "No Valid Module Mode, Cannot be disabled from software\n");
                App_printf("Optional Clocks if any have been disabled\n");
            }
            else if (PM_SYS_CONFIG_MODULE_HAS_DEPENDENCIES ==
                     resultReturn.failCause)
            {
                App_printf("Module has dependencies\n");
            }
            else
            {
                App_printf(
                    "PMLIB_SYS_CONFIG_DISABLED FAIL :Error Code Returned : %d\n",
                    resultReturn.failCause);
                finalSuccess = PM_FAIL;
            }
        }
    }
}

void retentionConfig(void)
{
    pmlibSysConfigPowerStateParams_t inputTable;
    pmlibSysConfigErrReturn_t        resultReturn;
    uint32_t idx;
    pmlibSysConfigPowerState_t       pwrSt;
    int32_t status = PM_SUCCESS;
    pwrSt = PMLIB_SYS_CONFIG_RETENTION;
    for (idx = 0U; idx < sizeof(gModuleNum)/sizeof(uint32_t); idx++)
    {
#if defined (SOC_AM65XX)
        if ((TISCI_DEV_NAVSS0 == gModuleNum[idx]) ||
            (TISCI_DEV_WKUP_UART0 == gModuleNum[idx]) ||
#if defined (BUILD_MPU1_0)
            (TISCI_DEV_COMPUTE_CLUSTER_A53_0 == gModuleNum[idx]) ||
            (TISCI_DEV_COMPUTE_CLUSTER_A53_1 == gModuleNum[idx]) ||
            (TISCI_DEV_COMPUTE_CLUSTER_A53_2 == gModuleNum[idx]) ||
            (TISCI_DEV_COMPUTE_CLUSTER_A53_3 == gModuleNum[idx]) ||
#endif
            (TISCI_DEV_DUMMY_IP_LPSC_DMSC_VD == gModuleNum[idx]))
        {
            continue;
        }
#endif

#if defined (SOC_J721E)
        if ((TISCI_DEV_MCU_NAVSS0 == gModuleNum[idx]) ||
            (TISCI_DEV_NAVSS0 == gModuleNum[idx]) ||
            (TISCI_DEV_EMIF_DATA_0_VD == gModuleNum[idx]) ||
            (TISCI_DEV_DDR0 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI0  == gModuleNum[idx]) ||
            (TISCI_DEV_RTI1  == gModuleNum[idx]) ||
            (TISCI_DEV_RTI24 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI25 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI16 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI15 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI28 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI29 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI30 == gModuleNum[idx]) ||
            (TISCI_DEV_RTI31 == gModuleNum[idx]) ||
        #if defined(BUILD_MCU1_0) || defined(BUILD_MCU1_1)
            (TISCI_DEV_MCU_R5FSS0_CORE1 == gModuleNum[idx]) ||
            (TISCI_DEV_MCU_R5FSS0_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MCU_0 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_MPU1_0)
            (TISCI_DEV_A72SS0_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_A72SS0_CORE1 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_MCU2_0)
            (TISCI_DEV_R5FSS0_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MAIN_0 == gModuleNum[idx]) ||
            (TISCI_DEV_TIMER14 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_MCU2_1)
            (TISCI_DEV_R5FSS0_CORE1 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MAIN_1 == gModuleNum[idx]) || 
        #endif
        #if defined (BUILD_MCU3_0)
            (TISCI_DEV_R5FSS1_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MAIN_0 == gModuleNum[idx]) || 
        #endif
        #if defined (BUILD_MCU3_1)
            (TISCI_DEV_R5FSS1_CORE1 == gModuleNum[idx]) ||
            (TISCI_DEV_PULSAR_SL_MAIN_1 == gModuleNum[idx]) || 
        #endif
        #if defined (BUILD_C66X_1)
            (TISCI_DEV_C66SS0_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_C66SS0_INTROUTER0 == gModuleNum[idx]) ||
            (TISCI_DEV_K3_C66_COREPAC_MAIN_0 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_C66X_2)
            (TISCI_DEV_C66SS1_CORE0 == gModuleNum[idx]) ||
            (TISCI_DEV_C66SS1_INTROUTER0 == gModuleNum[idx]) ||
            (TISCI_DEV_K3_C66_COREPAC_MAIN_1 == gModuleNum[idx]) ||
        #endif
        #if defined (BUILD_C7X_1)
            (TISCI_DEV_C71SS0 == gModuleNum[idx]) ||
            (TISCI_DEV_C71SS0_MMA == gModuleNum[idx]) ||
        #endif
            (TISCI_DEV_MCU_RTI0 == gModuleNum[idx]) ||
            (TISCI_DEV_MCU_RTI1 == gModuleNum[idx]) ||
            (TISCI_DEV_WKUP_UART0 == gModuleNum[idx]) ||
            (TISCI_DEV_UART9 == gModuleNum[idx]) ||
            (TISCI_DEV_DMSC_WKUP_0 == gModuleNum[idx]))
        {
            continue;
        }
#endif
        PMLIBSysConfigPowerStateParams_init(&inputTable, (uint32_t) 1U);
        inputTable.modId    = gModuleNum[idx];
        inputTable.pwrState = pwrSt;

        App_printf("%s", (char *) gModuleNames[idx]);
        App_printf(": ");
        status   = PMLIBSysConfigSetPowerState(&inputTable, (uint32_t) 1U,
                                               PM_TIMEOUT_INFINITE,
                                               &resultReturn);
        if (PM_SUCCESS == status)
        {
            App_printf("PASS\n");
        }
        else
        {
            if (PM_SYS_CONFIG_MODULE_CANNOT_BE_ENABLED ==
                resultReturn.failCause)
            {
                App_printf(
                    "No Valid Module Mode, Cannot be enabled from software\n");
                App_printf("Optional Clocks if any have been enabled\n");
            }
            else if (PM_SYS_CONFIG_MODULE_CANNOT_BE_AUTOCG ==
                     resultReturn.failCause)
            {
                App_printf("Cannot be auto clock gated\n");
            }
            else
            {
                App_printf(
                    "PMLIB_SYS_CONFIG_RETENTION FAIL :Error Code Returned : %d\n",
                    resultReturn.failCause);
                finalSuccess = PM_FAIL;
            }
        }
    }
}

