###############################################################################
#
# This script in intended to minize the amount of manual steps required for 
# PSDKQA addon package installation.  
#
# This script MUST be run from the PSDKRA installation directory, after the
# PSDKQA addon has been extracted.
#
# The invoking of this scripts MUST be
#
#    ./psdkqa/qnx/scripts/psdkqa_setup.sh
#
# The location of the BSP is determined by the user during installation of
# BSP from QNX Sofwtare Center.  This script is assuming that the BSP
# was downloaded to
#
#    ${QNX_BSP_PATH}/BSP_ti-j721e-am752x-evm_br-700_be-700_SVN915061_JBN29.zip
#
###############################################################################

# Paths to different locations with PSDKRA installation
PSDKRA_PATH=${PWD}
PSDKQA_PATH=${PSDKRA_PATH}/psdkqa
PDK_VERSION=pdk_jacinto_07_00_00
PDK_PATH=${PSDKRA_PATH}/${PDK_VERSION}
QNX_BASE=/home/$USER/qnx700

# The QNX installation directory may differ, but the
# download location of BSP from QNX Software Center
# should be resident in the same relative location
QNX_BSP_NAME=BSP_ti-j721e-am752x-evm_br-700_be-700_SVN915061_JBN29.zip
QNX_BSP_PATH=${QNX_BASE}/bsp


# Print off the configuration
print_variables()
{
  echo "For installation script to function below variables must be correct"
  echo "PSDKRA_PATH=${PWD}"
  echo "PSDKQA_PATH=${PSDKQA_PATH}"
  echo "PDK_PATH=${PDK_PATH}"
  echo "QNX_BSP_NAME=${QNX_BSP_NAME}"
  echo "QNX_BSP_PATH=${QNX_BSP_PATH}"
}

# Lets check the setup, before running the script
check_variables()
{
  # Check PSDKQA Path exists
  if [ ! -d ${QNX_PSDKQA_PATH} ]
    then
    echo "Invalid path to psdkqa, ${QNX_PSDKQA_PATH}"
    exit
  fi


  # Check BSP Path exists
  if [ ! -d ${QNX_BSP_PATH} ]
    then
    echo "Invalid path to ${QNX_BSP_PATH}"
    echo "${QNX_BSP_NAME} must be extracted and available at, ${QNX_BSP_PATH}"
    exit
  fi
 
  # Check BSP zip file exists
  if [ ! -f ${QNX_BSP_PATH}/${QNX_BSP_NAME} ]
    then
    echo "Invalid path to ${QNX_BSP_PATH}/${QNX_BSP_NAME}"
    echo "${QNX_BSP_NAME} must be extracted and available at, ${QNX_BSP_PATH}/bsp"
    exit
  fi

  # Check that PDK directory exists
  if [ ! -d ${PDK_PATH} ]
    then
    echo "Invalid PDK_PATH ${PDK_PATH}"
    exit
  fi
}


setup_qnx_bsp_in_psdkqa()
{
  # Extract QNX BSP to psdkqa/qnx/bsp
  mkdir -p ${PSDKQA_PATH}/qnx/bsp
  unzip ${QNX_BSP_PATH}/${QNX_BSP_NAME} -d ${PSDKQA_PATH}/qnx/bsp

  # Update the QNX BSP with some TI BSP files
  cp -Rv ${PSDKQA_PATH}/qnx/scripts/bsp/* ${PSDKQA_PATH}/qnx/bsp/

}

setup_qnx_pdk_in_psdkqa()
{
  # Copy the PDK from PSDKRA to PSDKQA
  mkdir ${PSDKQA_PATH}/pdk
  cp -Rv ${PDK_PATH}/packages ${PSDKQA_PATH}/pdk/

  # Copy modified PDK files 
  cp -Rv ${PSDKQA_PATH}/qnx/pdk/* ${PSDKQA_PATH}/pdk/
}

print_variables
check_variables
setup_qnx_bsp_in_psdkqa
setup_qnx_pdk_in_psdkqa
